@@ -401,7 +401,7 @@ const AuthPrompt = new Lang.Class({
     },
 
     updateSensitivity: function(sensitive) {
-        this._updateNextButtonSensitivity(sensitive);
+        this._updateNextButtonSensitivity(sensitive && this._entry.text.length > 0);
         this._entry.reactive = sensitive;
         this._entry.clutter_text.editable = sensitive;
     },
@@ -432,8 +432,9 @@ const AuthPrompt = new Lang.Class({
         let oldStatus = this.verificationStatus;
         this.verificationStatus = AuthPromptStatus.NOT_VERIFYING;
         this.cancelButton.reactive = true;
+        this.nextButton.label = _("Next");
 
-        if (oldStatus == AuthPromptStatus.VERIFYING)
+        if (this._userVerifier)
             this._userVerifier.cancel();
 
         this._queryingService = null;
@@ -488,6 +489,7 @@ const AuthPrompt = new Lang.Class({
 
     finish: function(onComplete) {
         if (!this._userVerifier.hasPendingMessages) {
+            this._userVerifier.clear();
             onComplete();
             return;
         }
@@ -495,12 +497,13 @@ const AuthPrompt = new Lang.Class({
         let signalId = this._userVerifier.connect('no-more-messages',
                                                   Lang.bind(this, function() {
                                                       this._userVerifier.disconnect(signalId);
+                                                      this._userVerifier.clear();
                                                       onComplete();
                                                   }));
     },
 
     cancel: function() {
-        if (this.verificationStatus == AuthPromptStatus.NOT_VERIFYING || this.verificationStatus == AuthPromptStatus.VERIFICATION_SUCCEEDED) {
+        if (this.verificationStatus == AuthPromptStatus.VERIFICATION_SUCCEEDED) {
             return;
         }
         this.reset();
