@@ -1106,6 +1106,8 @@ const Message = new Lang.Class({
             this._bodyStack.layout_manager.expansion = 1;
             this._actionBin.scale_y = 1;
         }
+
+        this.emit('expanded');
     },
 
     unexpand: function(animate) {
@@ -1128,6 +1130,8 @@ const Message = new Lang.Class({
             this._actionBin.scale_y = 0;
             this.expanded = false;
         }
+
+        this.emit('unexpanded');
     },
 
     canClose: function() {
@@ -1225,7 +1229,7 @@ const NotificationMessage = new Lang.Class({
                 this._closed = true;
                 this.notification.destroy(MessageTray.NotificationDestroyedReason.DISMISSED);
             }));
-        notification.connect('destroy', Lang.bind(this,
+        this._destroyId = notification.connect('destroy', Lang.bind(this,
             function() {
                 if (!this._closed)
                     this.close();
@@ -1248,10 +1252,6 @@ const NotificationMessage = new Lang.Class({
         this.setUseBodyMarkup(n.bannerBodyMarkup);
     },
 
-    canClose: function() {
-        return !this.notification.resident;
-    },
-
     _onClicked: function() {
         this.notification.activate();
     },
@@ -1260,6 +1260,10 @@ const NotificationMessage = new Lang.Class({
         if (this._updatedId)
             this.notification.disconnect(this._updatedId);
         this._updatedId = 0;
+
+        if (this._destroyId)
+            this.notification.disconnect(this._destroyId);
+        this._destroyId = 0;
     }
 });
 
