@@ -933,6 +933,14 @@ const Panel = new Lang.Class({
         this._updateBox(panel.center, this._centerBox);
         this._updateBox(panel.right, this._rightBox);
 
+        if (panel.left.indexOf('dateMenu') != -1)
+            Main.messageTray.bannerAlignment = Clutter.ActorAlign.START;
+        else if (panel.right.indexOf('dateMenu') != -1)
+            Main.messageTray.bannerAlignment = Clutter.ActorAlign.END;
+        // Default to center if there is no dateMenu
+        else
+            Main.messageTray.bannerAlignment = Clutter.ActorAlign.CENTER;
+
         if (this._sessionStyle)
             this._removeStyleClassName(this._sessionStyle);
 
@@ -995,6 +1003,7 @@ const Panel = new Lang.Class({
         if (parent)
             parent.remove_actor(container);
 
+
         box.insert_child_at_index(container, position);
         if (indicator.menu)
             this.menuManager.addMenu(indicator.menu);
@@ -1004,6 +1013,8 @@ const Panel = new Lang.Class({
             emitter.disconnect(destroyId);
             container.destroy();
         }));
+        indicator.connect('menu-set', Lang.bind(this, this._onMenuSet));
+        this._onMenuSet(indicator);
     },
 
     addToStatusArea: function(role, indicator, position, box) {
@@ -1035,5 +1046,24 @@ const Panel = new Lang.Class({
         this.actor.remove_style_class_name(className);
         this._rightCorner.actor.remove_style_class_name(className);
         this._leftCorner.actor.remove_style_class_name(className);
+    },
+
+    _onMenuSet: function(indicator) {
+        if (!indicator.menu || indicator.menu._openChangedId > 0)
+            return;
+
+        indicator.menu._openChangedId = indicator.menu.connect('open-state-changed',
+            Lang.bind(this, function(menu, isOpen) {
+                let boxAlignment;
+                if (this._leftBox.contains(indicator.container))
+                    boxAlignment = Clutter.ActorAlign.START;
+                else if (this._centerBox.contains(indicator.container))
+                    boxAlignment = Clutter.ActorAlign.CENTER;
+                else if (this._rightBox.contains(indicator.container))
+                    boxAlignment = Clutter.ActorAlign.END;
+
+                if (boxAlignment == Main.messageTray.bannerAlignment)
+                    Main.messageTray.bannerBlocked = isOpen;
+            }));
     }
 });
