@@ -12,7 +12,6 @@ const BoxPointer = imports.ui.boxpointer;
 const GrabHelper = imports.ui.grabHelper;
 const Main = imports.ui.main;
 const Params = imports.misc.params;
-const Separator = imports.ui.separator;
 const Tweener = imports.ui.tweener;
 
 const Ornament = {
@@ -170,10 +169,10 @@ const PopupBaseMenuItem = new Lang.Class({
         if (activeChanged) {
             this.active = active;
             if (active) {
-                this.actor.add_style_class_name('active');
+                this.actor.add_style_class_name('selected');
                 this.actor.grab_key_focus();
             } else {
-                this.actor.remove_style_class_name('active');
+                this.actor.remove_style_class_name('selected');
                 // Remove the CSS active state if the user press the button and
                 // while holding moves to another menu item, so we don't paint all items.
                 // The correct behaviour would be to set the new item with the CSS
@@ -264,7 +263,9 @@ const PopupSeparatorMenuItem = new Lang.Class({
                            Lang.bind(this, this._syncVisibility));
         this._syncVisibility();
 
-        this._separator = new St.Widget({ style_class: 'popup-separator-menu-item' });
+        this._separator = new St.Widget({ style_class: 'popup-separator-menu-item',
+                                          y_expand: true,
+                                          y_align: Clutter.ActorAlign.CENTER });
         this.actor.add(this._separator, { expand: true });
     },
 
