@@ -40,6 +40,8 @@
 static void gnome_shell_plugin_start            (MetaPlugin          *plugin);
 static void gnome_shell_plugin_minimize         (MetaPlugin          *plugin,
                                                  MetaWindowActor     *actor);
+static void gnome_shell_plugin_unminimize       (MetaPlugin          *plugin,
+                                                 MetaWindowActor     *actor);
 static void gnome_shell_plugin_maximize         (MetaPlugin          *plugin,
                                                  MetaWindowActor     *actor,
                                                  gint                 x,
@@ -106,10 +108,6 @@ struct _GnomeShellPlugin
 {
   MetaPlugin parent;
 
-  Atom panel_action;
-  Atom panel_action_run_dialog;
-  Atom panel_action_main_menu;
-
   int glx_error_base;
   int glx_event_base;
   guint have_swap_event : 1;
@@ -135,6 +133,7 @@ gnome_shell_plugin_class_init (GnomeShellPluginClass *klass)
   plugin_class->start            = gnome_shell_plugin_start;
   plugin_class->map              = gnome_shell_plugin_map;
   plugin_class->minimize         = gnome_shell_plugin_minimize;
+  plugin_class->unminimize       = gnome_shell_plugin_unminimize;
   plugin_class->maximize         = gnome_shell_plugin_maximize;
   plugin_class->unmaximize       = gnome_shell_plugin_unmaximize;
   plugin_class->destroy          = gnome_shell_plugin_destroy;
@@ -272,6 +271,15 @@ gnome_shell_plugin_minimize (MetaPlugin         *plugin,
 
 }
 
+static void
+gnome_shell_plugin_unminimize (MetaPlugin         *plugin,
+                               MetaWindowActor    *actor)
+{
+  _shell_wm_unminimize (get_shell_wm (),
+                      actor);
+
+}
+
 static void
 gnome_shell_plugin_maximize (MetaPlugin         *plugin,
                              MetaWindowActor    *actor,
