@@ -45,6 +45,11 @@ GdkPixbuf *shell_util_create_pixbuf_from_data (const guchar      *data,
 void    shell_util_cursor_tracker_to_clutter (MetaCursorTracker *tracker,
                                               ClutterTexture    *texture);
 
+gboolean shell_util_need_background_refresh (void);
+
+void shell_util_text_insert_keyval (ClutterActor *actor,
+                                    guint         keyval);
+
 G_END_DECLS
 
 #endif /* __SHELL_UTIL_H__ */
